Index: /trunk/include/iprt/file.h
===================================================================
--- /trunk/include/iprt/file.h	(revision 80584)
+++ /trunk/include/iprt/file.h	(revision 80585)
@@ -94,7 +94,7 @@
  * @param   pcbFile         Where to return the file size (bytes).
  *
- * @sa      RTFileGetSize, RTPathQueryInfoEx.
- */
-RTDECL(int) RTFileQuerySize(const char *pszPath, uint64_t *pcbFile);
+ * @sa      RTFileQuerySize, RTPathQueryInfoEx.
+ */
+RTDECL(int) RTFileQuerySizeByPath(const char *pszPath, uint64_t *pcbFile);
 
 
@@ -560,5 +560,5 @@
  * @param   pcbSize     Where to store the filesize.
  */
-RTDECL(int)  RTFileGetSize(RTFILE File, uint64_t *pcbSize);
+RTDECL(int)  RTFileQuerySize(RTFILE File, uint64_t *pcbSize);
 
 /**
@@ -568,5 +568,5 @@
  *          -1 on failure, the file position is undefined.
  * @param   File        Handle to the file.
- * @see     RTFileGetMaxSizeEx.
+ * @see     RTFileQueryMaxSizeEx.
  */
 RTDECL(RTFOFF) RTFileGetMaxSize(RTFILE File);
@@ -580,5 +580,5 @@
  * @see     RTFileGetMaxSize.
  */
-RTDECL(int) RTFileGetMaxSizeEx(RTFILE File, PRTFOFF pcbMax);
+RTDECL(int) RTFileQueryMaxSizeEx(RTFILE File, PRTFOFF pcbMax);
 
 /**
Index: /trunk/include/iprt/mangling.h
===================================================================
--- /trunk/include/iprt/mangling.h	(revision 80584)
+++ /trunk/include/iprt/mangling.h	(revision 80585)
@@ -932,6 +932,6 @@
 # define RTFileFromNative                               RT_MANGLER(RTFileFromNative)
 # define RTFileGetMaxSize                               RT_MANGLER(RTFileGetMaxSize)
-# define RTFileGetMaxSizeEx                             RT_MANGLER(RTFileGetMaxSizeEx)
-# define RTFileGetSize                                  RT_MANGLER(RTFileGetSize)
+# define RTFileQueryMaxSizeEx                           RT_MANGLER(RTFileQueryMaxSizeEx)
+# define RTFileQuerySizeByPath                          RT_MANGLER(RTFileQuerySizeByPath)
 # define RTFileIoCtl                                    RT_MANGLER(RTFileIoCtl)
 # define RTFileIsValid                                  RT_MANGLER(RTFileIsValid)
@@ -2640,5 +2640,5 @@
 # define RTVfsFileFromRTFile                            RT_MANGLER(RTVfsFileFromRTFile)
 # define RTVfsFileGetOpenFlags                          RT_MANGLER(RTVfsFileGetOpenFlags)
-# define RTVfsFileGetSize                               RT_MANGLER(RTVfsFileGetSize)
+# define RTVfsFileQuerySize                             RT_MANGLER(RTVfsFileQuerySize)
 # define RTVfsFileGetMaxSize                            RT_MANGLER(RTVfsFileGetMaxSize)
 # define RTVfsFileOpen                                  RT_MANGLER(RTVfsFileOpen)
Index: /trunk/include/iprt/vfs.h
===================================================================
--- /trunk/include/iprt/vfs.h	(revision 80584)
+++ /trunk/include/iprt/vfs.h	(revision 80585)
@@ -1475,5 +1475,5 @@
 
 
-RTDECL(int)         RTVfsFileGetSize(RTVFSFILE hVfsFile, uint64_t *pcbSize);
+RTDECL(int)         RTVfsFileQuerySize(RTVFSFILE hVfsFile, uint64_t *pcbSize);
 RTDECL(RTFOFF)      RTVfsFileGetMaxSize(RTVFSFILE hVfsFile);
 RTDECL(int)         RTVfsFileQueryMaxSize(RTVFSFILE hVfsFile, uint64_t *pcbMax);
Index: /trunk/include/iprt/vfslowlevel.h
===================================================================
--- /trunk/include/iprt/vfslowlevel.h	(revision 80584)
+++ /trunk/include/iprt/vfslowlevel.h	(revision 80585)
@@ -1023,5 +1023,5 @@
      * @param   pvThis      The implementation specific file data.
      * @param   pcbFile     Where to store the current file size.
-     * @sa      RTFileGetSize
+     * @sa      RTFileQuerySize
      */
     DECLCALLBACKMEMBER(int, pfnQuerySize)(void *pvThis, uint64_t *pcbFile);
@@ -1057,5 +1057,5 @@
      * @param   pcbMax      Where to return the max file size.
      * @note    Optional.  If NULL, VERR_NOT_IMPLEMENTED will be returned.
-     * @sa      RTFileGetMaxSizeEx
+     * @sa      RTFileQueryMaxSizeEx
      */
     DECLCALLBACKMEMBER(int, pfnQueryMaxSize)(void *pvThis, uint64_t *pcbMax);
Index: /trunk/src/VBox/Devices/Graphics/DevVGA.cpp
===================================================================
--- /trunk/src/VBox/Devices/Graphics/DevVGA.cpp	(revision 80584)
+++ /trunk/src/VBox/Devices/Graphics/DevVGA.cpp	(revision 80585)
@@ -6680,5 +6680,5 @@
         if (RT_SUCCESS(rc))
         {
-            rc = RTFileGetSize(FileVgaBios, &pThis->cbVgaBios);
+            rc = RTFileQuerySize(FileVgaBios, &pThis->cbVgaBios);
             if (RT_SUCCESS(rc))
             {
@@ -7090,5 +7090,5 @@
         {
             uint64_t cbFile;
-            rc = RTFileGetSize(FileLogo, &cbFile);
+            rc = RTFileQuerySize(FileLogo, &cbFile);
             if (RT_SUCCESS(rc))
             {
Index: /trunk/src/VBox/Devices/Network/slirp/tftp.c
===================================================================
--- /trunk/src/VBox/Devices/Network/slirp/tftp.c	(revision 80584)
+++ /trunk/src/VBox/Devices/Network/slirp/tftp.c	(revision 80585)
@@ -449,5 +449,5 @@
     }
 
-    rc = RTFileGetSize(hSessionFile, &cbSessionFile);
+    rc = RTFileQuerySize(hSessionFile, &cbSessionFile);
     RTFileClose(hSessionFile);
     if (RT_FAILURE(rc))
Index: /trunk/src/VBox/Devices/PC/ACPI/VBoxAcpi.cpp
===================================================================
--- /trunk/src/VBox/Devices/PC/ACPI/VBoxAcpi.cpp	(revision 80584)
+++ /trunk/src/VBox/Devices/PC/ACPI/VBoxAcpi.cpp	(revision 80585)
@@ -307,5 +307,5 @@
              */
             uint64_t cbAmlFile = 0;
-            rc = RTFileGetSize(FileAml, &cbAmlFile);
+            rc = RTFileQuerySize(FileAml, &cbAmlFile);
 
             cbAmlCode = (size_t)cbAmlFile;
Index: /trunk/src/VBox/Devices/PC/DevACPI.cpp
===================================================================
--- /trunk/src/VBox/Devices/PC/DevACPI.cpp	(revision 80584)
+++ /trunk/src/VBox/Devices/PC/DevACPI.cpp	(revision 80585)
@@ -3118,5 +3118,5 @@
     if (RT_SUCCESS(rc))
     {
-        rc = RTFileGetSize(FileCUSTBin, pcbCustBin);
+        rc = RTFileQuerySize(FileCUSTBin, pcbCustBin);
         if (RT_SUCCESS(rc))
         {
Index: /trunk/src/VBox/Devices/PC/DevPcBios.cpp
===================================================================
--- /trunk/src/VBox/Devices/PC/DevPcBios.cpp	(revision 80584)
+++ /trunk/src/VBox/Devices/PC/DevPcBios.cpp	(revision 80585)
@@ -1484,5 +1484,5 @@
             /* Figure the size and check restrictions. */
             uint64_t cbPcBios;
-            rc = RTFileGetSize(hFilePcBios, &cbPcBios);
+            rc = RTFileQuerySize(hFilePcBios, &cbPcBios);
             if (RT_SUCCESS(rc))
             {
@@ -1679,5 +1679,5 @@
             if (RT_SUCCESS(rc))
             {
-                rc = RTFileGetSize(hFileLanBoot, &cbFileLanBoot);
+                rc = RTFileQuerySize(hFileLanBoot, &cbFileLanBoot);
                 if (RT_SUCCESS(rc))
                 {
Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxInternalManage.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxInternalManage.cpp	(revision 80584)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxInternalManage.cpp	(revision 80585)
@@ -1288,5 +1288,5 @@
          */
         vrc = RTErrConvertFromWin32(GetLastError());
-        if (RT_FAILURE(RTFileGetSize(hRawFile, &cbSize)))
+        if (RT_FAILURE(RTFileQuerySize(hRawFile, &cbSize)))
         {
             RTMsgError("Cannot get the geometry of the raw disk '%s': %Rrc", rawdisk.c_str(), vrc);
@@ -1338,5 +1338,5 @@
         else if (S_ISREG(DevStat.st_mode))
         {
-            vrc = RTFileGetSize(hRawFile, &cbSize);
+            vrc = RTFileQuerySize(hRawFile, &cbSize);
             if (RT_FAILURE(vrc))
             {
@@ -1393,5 +1393,5 @@
         {
             fRelative = false; /* Must be false for raw image files. */
-            vrc = RTFileGetSize(hRawFile, &cbSize);
+            vrc = RTFileQuerySize(hRawFile, &cbSize);
             if (RT_FAILURE(vrc))
             {
@@ -1431,5 +1431,5 @@
         else if (S_ISREG(DevStat.st_mode))
         {
-            vrc = RTFileGetSize(hRawFile, &cbSize);
+            vrc = RTFileQuerySize(hRawFile, &cbSize);
             if (RT_FAILURE(vrc))
             {
@@ -1493,5 +1493,5 @@
     /* Hopefully this works on all other hosts. If it doesn't, it'll just fail
      * creating the VMDK, so no real harm done. */
-    vrc = RTFileGetSize(hRawFile, &cbSize);
+    vrc = RTFileQuerySize(hRawFile, &cbSize);
     if (RT_FAILURE(vrc))
     {
Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxManageControlVM.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxManageControlVM.cpp	(revision 80584)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxManageControlVM.cpp	(revision 80585)
@@ -321,5 +321,5 @@
     {
         uint64_t cbFile = 0;
-        vrc = RTFileGetSize(File, &cbFile);
+        vrc = RTFileQuerySize(File, &cbFile);
         if (RT_SUCCESS(vrc))
         {
Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxManageDisk.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxManageDisk.cpp	(revision 80584)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxManageDisk.cpp	(revision 80585)
@@ -1187,5 +1187,5 @@
         cbFile = RTStrToUInt64(filesize);
     else
-        rc = RTFileGetSize(File, &cbFile);
+        rc = RTFileQuerySize(File, &cbFile);
     if (RT_FAILURE(rc))
     {
Index: /trunk/src/VBox/Frontends/VBoxManage/VBoxManageModifyVM.cpp
===================================================================
--- /trunk/src/VBox/Frontends/VBoxManage/VBoxManageModifyVM.cpp	(revision 80584)
+++ /trunk/src/VBox/Frontends/VBoxManage/VBoxManageModifyVM.cpp	(revision 80585)
@@ -590,5 +590,5 @@
                 }
                 uint64_t cbSize;
-                vrc = RTFileGetSize(iconFile, &cbSize);
+                vrc = RTFileQuerySize(iconFile, &cbSize);
                 if (RT_FAILURE(vrc))
                 {
Index: /trunk/src/VBox/Main/src-all/TextScript.cpp
===================================================================
--- /trunk/src/VBox/Main/src-all/TextScript.cpp	(revision 80584)
+++ /trunk/src/VBox/Main/src-all/TextScript.cpp	(revision 80585)
@@ -65,5 +65,5 @@
     HRESULT  hrc;
     uint64_t cbFile = 0;
-    int vrc = RTVfsFileGetSize(hVfsFile, &cbFile);
+    int vrc = RTVfsFileQuerySize(hVfsFile, &cbFile);
     if (   RT_SUCCESS(vrc)
         && cbFile < _16M)
@@ -108,5 +108,5 @@
                                       mpSetError->tr("'%s' is too big (max 16MB): %'RU64"), pszFilename, cbFile);
     else
-        hrc = mpSetError->setErrorVrc(vrc, mpSetError->tr("RTVfsFileGetSize failed (%Rrc)"), vrc);
+        hrc = mpSetError->setErrorVrc(vrc, mpSetError->tr("RTVfsFileQuerySize failed (%Rrc)"), vrc);
     return hrc;
 }
Index: /trunk/src/VBox/Main/src-client/ConsoleImpl2.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/ConsoleImpl2.cpp	(revision 80584)
+++ /trunk/src/VBox/Main/src-client/ConsoleImpl2.cpp	(revision 80585)
@@ -3969,5 +3969,5 @@
                 RTFOFF maxSize;
                 /* Careful: This function will work only on selected local file systems! */
-                rc = RTFileGetMaxSizeEx(file, &maxSize);
+                rc = RTFileQueryMaxSizeEx(file, &maxSize);
                 RTFileClose(file);
                 if (   RT_SUCCESS(rc)
Index: /trunk/src/VBox/Main/src-client/GuestSessionImplTasks.cpp
===================================================================
--- /trunk/src/VBox/Main/src-client/GuestSessionImplTasks.cpp	(revision 80584)
+++ /trunk/src/VBox/Main/src-client/GuestSessionImplTasks.cpp	(revision 80585)
@@ -1979,5 +1979,5 @@
     {
         uint64_t cbSrcSize = 0;
-        rc = RTVfsFileGetSize(hVfsFile, &cbSrcSize);
+        rc = RTVfsFileQuerySize(hVfsFile, &cbSrcSize);
         if (RT_SUCCESS(rc))
         {
Index: /trunk/src/VBox/Main/src-server/MachineImplCloneVM.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/MachineImplCloneVM.cpp	(revision 80584)
+++ /trunk/src/VBox/Main/src-server/MachineImplCloneVM.cpp	(revision 80585)
@@ -222,5 +222,5 @@
         sst.strSaveStateFile = bstrSrcSaveStatePath;
         uint64_t cbSize;
-        int vrc = RTFileQuerySize(sst.strSaveStateFile.c_str(), &cbSize);
+        int vrc = RTFileQuerySizeByPath(sst.strSaveStateFile.c_str(), &cbSize);
         if (RT_FAILURE(vrc))
             return p->setErrorBoth(VBOX_E_IPRT_ERROR, vrc, p->tr("Could not query file size of '%s' (%Rrc)"),
Index: /trunk/src/VBox/Main/src-server/MachineImplMoveVM.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/MachineImplMoveVM.cpp	(revision 80584)
+++ /trunk/src/VBox/Main/src-server/MachineImplMoveVM.cpp	(revision 80585)
@@ -393,5 +393,5 @@
             if (name.contains(strSettingsFilePath))
             {
-                vrc = RTFileQuerySize(name.c_str(), &cbFile);
+                vrc = RTFileQuerySizeByPath(name.c_str(), &cbFile);
                 if (RT_SUCCESS(vrc))
                 {
@@ -448,5 +448,5 @@
 
                     uint64_t cbFile = 0;
-                    vrc = RTFileQuerySize(strFile.c_str(), &cbFile);
+                    vrc = RTFileQuerySizeByPath(strFile.c_str(), &cbFile);
                     if (RT_SUCCESS(vrc))
                     {
@@ -1297,5 +1297,5 @@
                 Utf8Str fullPath =  it->first;
                 fullPath.append(RTPATH_DELIMITER).append(it->second);
-                vrc = RTFileQuerySize(fullPath.c_str(), &cbFile);
+                vrc = RTFileQuerySizeByPath(fullPath.c_str(), &cbFile);
                 if (RT_SUCCESS(vrc))
                 {
@@ -1482,5 +1482,5 @@
         uint64_t cbSize;
 
-        int vrc = RTFileQuerySize(sst.strSaveStateFile.c_str(), &cbSize);
+        int vrc = RTFileQuerySizeByPath(sst.strSaveStateFile.c_str(), &cbSize);
         if (RT_FAILURE(vrc))
             return m_pMachine->setErrorBoth(VBOX_E_IPRT_ERROR, vrc,
Index: /trunk/src/VBox/Main/src-server/MediumImpl.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/MediumImpl.cpp	(revision 80584)
+++ /trunk/src/VBox/Main/src-server/MediumImpl.cpp	(revision 80585)
@@ -5547,8 +5547,8 @@
         if (i_isMediumFormatFile() && pOther->i_isMediumFormatFile())
         {
-            vrc = RTFileQuerySize(this->i_getLocationFull().c_str(), &cbMediumThis);
+            vrc = RTFileQuerySizeByPath(this->i_getLocationFull().c_str(), &cbMediumThis);
             if (RT_SUCCESS(vrc))
             {
-                vrc = RTFileQuerySize(pOther->i_getLocationFull().c_str(),
+                vrc = RTFileQuerySizeByPath(pOther->i_getLocationFull().c_str(),
                                       &cbMediumOther);
             }
Index: /trunk/src/VBox/Main/src-server/generic/AutostartDb-generic.cpp
===================================================================
--- /trunk/src/VBox/Main/src-server/generic/AutostartDb-generic.cpp	(revision 80584)
+++ /trunk/src/VBox/Main/src-server/generic/AutostartDb-generic.cpp	(revision 80585)
@@ -72,5 +72,5 @@
                  * should be really really small. Anything else is bogus.
                  */
-                rc = RTFileGetSize(hAutostartFile, &cbFile);
+                rc = RTFileQuerySize(hAutostartFile, &cbFile);
                 if (   RT_SUCCESS(rc)
                     && cbFile <= 16)
Index: /trunk/src/VBox/Runtime/VBox/VBoxRTImp.def
===================================================================
--- /trunk/src/VBox/Runtime/VBox/VBoxRTImp.def	(revision 80584)
+++ /trunk/src/VBox/Runtime/VBox/VBoxRTImp.def	(revision 80585)
@@ -1023,6 +1023,6 @@
     RTFileFromNative
     RTFileGetMaxSize
-    RTFileGetMaxSizeEx
-    RTFileGetSize
+    RTFileQueryMaxSizeEx
+    RTFileQuerySizeByPath
     RTFileIoCtl             ; not-win
     RTFileIsValid
@@ -2098,5 +2098,5 @@
     RTVfsFileGetMaxSize
     RTVfsFileGetOpenFlags
-    RTVfsFileGetSize
+    RTVfsFileQuerySize
     RTVfsFileOpen
     RTVfsFileOpenNormal
Index: /trunk/src/VBox/Runtime/common/checksum/RTSha1Digest.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/checksum/RTSha1Digest.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/checksum/RTSha1Digest.cpp	(revision 80585)
@@ -124,5 +124,5 @@
     {
         uint64_t cbFile;
-        rc = RTFileGetSize(hFile, &cbFile);
+        rc = RTFileQuerySize(hFile, &cbFile);
         if (RT_FAILURE(rc))
         {
Index: /trunk/src/VBox/Runtime/common/checksum/RTSha256Digest.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/checksum/RTSha256Digest.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/checksum/RTSha256Digest.cpp	(revision 80585)
@@ -128,5 +128,5 @@
     {
         uint64_t cbFile;
-        rc = RTFileGetSize(hFile, &cbFile);
+        rc = RTFileQuerySize(hFile, &cbFile);
         if (RT_FAILURE(rc))
         {
Index: /trunk/src/VBox/Runtime/common/checksum/manifest.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/checksum/manifest.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/checksum/manifest.cpp	(revision 80585)
@@ -118,5 +118,5 @@
     {
         uint64_t cbSize;
-        rc = RTFileGetSize(file, &cbSize);
+        rc = RTFileQuerySize(file, &cbSize);
         if (RT_FAILURE(rc))
             break;
Index: /trunk/src/VBox/Runtime/common/dbg/dbgmodmapsym.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dbg/dbgmodmapsym.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/dbg/dbgmodmapsym.cpp	(revision 80585)
@@ -525,5 +525,5 @@
     {
         uint64_t cbFile = 0;
-        rc = RTFileGetSize(hFile, &cbFile);
+        rc = RTFileQuerySize(hFile, &cbFile);
         if (   RT_SUCCESS(rc)
             && cbFile < _2M)
Index: /trunk/src/VBox/Runtime/common/dvm/dvm.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/dvm/dvm.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/dvm/dvm.cpp	(revision 80585)
@@ -202,5 +202,5 @@
 
     uint64_t cbDisk;
-    int rc = RTVfsFileGetSize(hVfsFile, &cbDisk);
+    int rc = RTVfsFileQuerySize(hVfsFile, &cbDisk);
     if (RT_SUCCESS(rc))
     {
Index: /trunk/src/VBox/Runtime/common/fs/extvfs.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/extvfs.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/extvfs.cpp	(revision 80585)
@@ -2723,5 +2723,5 @@
         RTListInit(&pThis->LstBlockLru);
 
-        rc = RTVfsFileGetSize(pThis->hVfsBacking, &pThis->cbBacking);
+        rc = RTVfsFileQuerySize(pThis->hVfsBacking, &pThis->cbBacking);
         if (RT_SUCCESS(rc))
         {
Index: /trunk/src/VBox/Runtime/common/fs/fatvfs.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/fatvfs.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/fatvfs.cpp	(revision 80585)
@@ -5620,5 +5620,5 @@
      * Get stuff that may fail.
      */
-    int rc = RTVfsFileGetSize(hVfsBacking, &pThis->cbBacking);
+    int rc = RTVfsFileQuerySize(hVfsBacking, &pThis->cbBacking);
     if (RT_FAILURE(rc))
         return rc;
@@ -5816,5 +5816,5 @@
     {
         uint64_t cbFile;
-        rc = RTVfsFileGetSize(hVfsFile, &cbFile);
+        rc = RTVfsFileQuerySize(hVfsFile, &cbFile);
         AssertRCReturn(rc, rc);
         AssertMsgReturn(cbFile > offVol, ("cbFile=%#RX64 offVol=%#RX64\n", cbFile, offVol), VERR_INVALID_PARAMETER);
Index: /trunk/src/VBox/Runtime/common/fs/isomaker.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/isomaker.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/isomaker.cpp	(revision 80585)
@@ -6248,5 +6248,5 @@
      */
     uint64_t cbResult = 0;
-    rc = RTVfsFileGetSize(hVfsFile, &cbResult);
+    rc = RTVfsFileQuerySize(hVfsFile, &cbResult);
     if (RT_SUCCESS(rc) && cbResult == pFile->cbData)
     {
Index: /trunk/src/VBox/Runtime/common/fs/isomakercmd.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/isomakercmd.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/isomakercmd.cpp	(revision 80585)
@@ -1105,5 +1105,5 @@
      */
     uint64_t cbImage;
-    int rc = RTVfsFileGetSize(hVfsSrcFile, &cbImage);
+    int rc = RTVfsFileQuerySize(hVfsSrcFile, &cbImage);
     if (RT_SUCCESS(rc))
     {
@@ -1160,5 +1160,5 @@
     }
     else
-        rc = rtFsIsoMakerCmdErrorRc(pOpts, rc, "RTVfsFileGetSize failed: %Rrc", rc);
+        rc = rtFsIsoMakerCmdErrorRc(pOpts, rc, "RTVfsFileQuerySize failed: %Rrc", rc);
     return rc;
 }
@@ -3075,5 +3075,5 @@
 
     uint64_t cbFile = 0;
-    rc = RTVfsFileGetSize(hVfsFile, &cbFile);
+    rc = RTVfsFileQuerySize(hVfsFile, &cbFile);
     if (RT_SUCCESS(rc))
     {
@@ -3127,5 +3127,5 @@
     }
     else
-        rtFsIsoMakerCmdErrorRc(pOpts, rc, "%s: RTVfsFileGetSize failed: %Rrc", pszFileSpec, rc);
+        rtFsIsoMakerCmdErrorRc(pOpts, rc, "%s: RTVfsFileQuerySize failed: %Rrc", pszFileSpec, rc);
     RTVfsFileRelease(hVfsFile);
     return rc;
Index: /trunk/src/VBox/Runtime/common/fs/isomakerimport.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/isomakerimport.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/isomakerimport.cpp	(revision 80585)
@@ -2521,5 +2521,5 @@
      */
     uint64_t cbSrcFile = 0;
-    int rc = RTVfsFileGetSize(hIsoFile, &cbSrcFile);
+    int rc = RTVfsFileQuerySize(hIsoFile, &cbSrcFile);
     if (RT_SUCCESS(rc))
     {
Index: /trunk/src/VBox/Runtime/common/fs/isovfs.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/isovfs.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/isovfs.cpp	(revision 80585)
@@ -5618,5 +5618,5 @@
      * Get stuff that may fail.
      */
-    int rc = RTVfsFileGetSize(hVfsBacking, &pThis->cbBacking);
+    int rc = RTVfsFileQuerySize(hVfsBacking, &pThis->cbBacking);
     if (RT_SUCCESS(rc))
         pThis->cBackingSectors = pThis->cbBacking / pThis->cbSector;
Index: /trunk/src/VBox/Runtime/common/fs/ntfsvfs.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/ntfsvfs.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/ntfsvfs.cpp	(revision 80585)
@@ -5536,5 +5536,5 @@
         RTListInit(&pThis->IdxNodeUnusedHead);
 
-        rc = RTVfsFileGetSize(pThis->hVfsBacking, &pThis->cbBacking);
+        rc = RTVfsFileQuerySize(pThis->hVfsBacking, &pThis->cbBacking);
         if (RT_SUCCESS(rc))
         {
Index: /trunk/src/VBox/Runtime/common/fs/xfsvfs.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fs/xfsvfs.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fs/xfsvfs.cpp	(revision 80585)
@@ -2327,5 +2327,5 @@
         RTListInit(&pThis->LstBlockLru);
 
-        rc = RTVfsFileGetSize(pThis->hVfsBacking, &pThis->cbBacking);
+        rc = RTVfsFileQuerySize(pThis->hVfsBacking, &pThis->cbBacking);
         if (RT_SUCCESS(rc))
         {
Index: /trunk/src/VBox/Runtime/common/fuzz/fuzz.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/fuzz/fuzz.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/fuzz/fuzz.cpp	(revision 80585)
@@ -1835,5 +1835,5 @@
     uint64_t cbFile = 0;
     void *pvCorpus = NULL;
-    int rc = RTVfsFileGetSize(hVfsFile, &cbFile);
+    int rc = RTVfsFileQuerySize(hVfsFile, &cbFile);
     if (RT_SUCCESS(rc))
     {
Index: /trunk/src/VBox/Runtime/common/ldr/ldrFile.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/ldr/ldrFile.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/ldr/ldrFile.cpp	(revision 80585)
@@ -225,5 +225,5 @@
         if (RT_SUCCESS(rc))
         {
-            rc = RTFileGetSize(pFileReader->hFile, &pFileReader->cbFile);
+            rc = RTFileQuerySize(pFileReader->hFile, &pFileReader->cbFile);
             if (RT_SUCCESS(rc))
             {
Index: /trunk/src/VBox/Runtime/common/ldr/ldrVfsFile.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/ldr/ldrVfsFile.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/ldr/ldrVfsFile.cpp	(revision 80585)
@@ -88,5 +88,5 @@
     PRTLDRREADERVFSFILE pFileReader = (PRTLDRREADERVFSFILE)pReader;
     uint64_t cbFile;
-    int rc = RTVfsFileGetSize(pFileReader->hVfsFile, &cbFile);
+    int rc = RTVfsFileQuerySize(pFileReader->hVfsFile, &cbFile);
     if (RT_SUCCESS(rc))
         return cbFile;
Index: /trunk/src/VBox/Runtime/common/log/log.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/log/log.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/log/log.cpp	(revision 80585)
@@ -3207,5 +3207,5 @@
     if (RT_SUCCESS(rc))
     {
-        rc = RTFileGetSize(pLogger->pInt->hFile, &pLogger->pInt->cbHistoryFileWritten);
+        rc = RTFileQuerySize(pLogger->pInt->hFile, &pLogger->pInt->cbHistoryFileWritten);
         if (RT_FAILURE(rc))
         {
Index: /trunk/src/VBox/Runtime/common/misc/inifile.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/inifile.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/misc/inifile.cpp	(revision 80585)
@@ -147,5 +147,5 @@
      */
     uint64_t cbFile;
-    int rc = RTVfsFileGetSize(pThis->hVfsFile, &cbFile);
+    int rc = RTVfsFileQuerySize(pThis->hVfsFile, &cbFile);
     AssertRCReturn(rc, rc);
 
Index: /trunk/src/VBox/Runtime/common/misc/s3.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/misc/s3.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/misc/s3.cpp	(revision 80585)
@@ -956,5 +956,5 @@
 
     uint64_t cbFileSize;
-    rc = RTFileGetSize(hFile, &cbFileSize);
+    rc = RTFileQuerySize(hFile, &cbFileSize);
     if (RT_FAILURE(rc))
     {
Index: /trunk/src/VBox/Runtime/common/vfs/vfsbase.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/vfs/vfsbase.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/vfs/vfsbase.cpp	(revision 80585)
@@ -4220,5 +4220,5 @@
 
 
-RTDECL(int) RTVfsFileGetSize(RTVFSFILE hVfsFile, uint64_t *pcbSize)
+RTDECL(int) RTVfsFileQuerySize(RTVFSFILE hVfsFile, uint64_t *pcbSize)
 {
     RTVFSFILEINTERNAL *pThis = hVfsFile;
Index: /trunk/src/VBox/Runtime/common/vfs/vfsprogress.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/vfs/vfsprogress.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/vfs/vfsprogress.cpp	(revision 80585)
@@ -402,5 +402,5 @@
 {
     PRTVFSPROGRESSFILE pThis = (PRTVFSPROGRESSFILE)pvThis;
-    return RTVfsFileGetSize(pThis->hVfsFile, pcbFile);
+    return RTVfsFileQuerySize(pThis->hVfsFile, pcbFile);
 }
 
Index: /trunk/src/VBox/Runtime/common/vfs/vfsreadahead.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/vfs/vfsreadahead.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/vfs/vfsreadahead.cpp	(revision 80585)
@@ -485,5 +485,5 @@
 
     RTCritSectEnter(&pThis->IoCritSect); /* paranoia */
-    int rc = RTVfsFileGetSize(pThis->hFile, pcbFile);
+    int rc = RTVfsFileQuerySize(pThis->hFile, pcbFile);
     RTCritSectLeave(&pThis->IoCritSect);
 
Index: /trunk/src/VBox/Runtime/common/vfs/vfsstdfile.cpp
===================================================================
--- /trunk/src/VBox/Runtime/common/vfs/vfsstdfile.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/common/vfs/vfsstdfile.cpp	(revision 80585)
@@ -111,5 +111,5 @@
 
     uint64_t cbFile;
-    int rc = RTFileGetSize(pThis->hFile, &cbFile);
+    int rc = RTFileQuerySize(pThis->hFile, &cbFile);
     if (RT_FAILURE(rc))
         return rc;
@@ -383,5 +383,5 @@
 {
     PRTVFSSTDFILE pThis = (PRTVFSSTDFILE)pvThis;
-    return RTFileGetSize(pThis->hFile, pcbFile);
+    return RTFileQuerySize(pThis->hFile, pcbFile);
 }
 
@@ -414,5 +414,5 @@
     PRTVFSSTDFILE pThis = (PRTVFSSTDFILE)pvThis;
     RTFOFF cbMax = 0;
-    int rc = RTFileGetMaxSizeEx(pThis->hFile, &cbMax);
+    int rc = RTFileQueryMaxSizeEx(pThis->hFile, &cbMax);
     if (RT_SUCCESS(rc))
         *pcbMax = cbMax;
Index: /trunk/src/VBox/Runtime/generic/RTFileCopyByHandlesEx-generic.cpp
===================================================================
--- /trunk/src/VBox/Runtime/generic/RTFileCopyByHandlesEx-generic.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/generic/RTFileCopyByHandlesEx-generic.cpp	(revision 80585)
@@ -59,5 +59,5 @@
      */
     uint64_t cbSrc;
-    rc = RTFileGetSize(hFileSrc, &cbSrc);
+    rc = RTFileQuerySize(hFileSrc, &cbSrc);
     if (RT_FAILURE(rc))
         return rc;
@@ -84,5 +84,5 @@
          */
         uint64_t cbDst;
-        rc = RTFileGetSize(hFileDst, &cbDst);
+        rc = RTFileQuerySize(hFileDst, &cbDst);
         if (RT_SUCCESS(rc) && cbDst > cbSrc)
             rc = RTFileSetSize(hFileDst, cbSrc);
Index: /trunk/src/VBox/Runtime/generic/RTFileQuerySize-generic.cpp
===================================================================
--- /trunk/src/VBox/Runtime/generic/RTFileQuerySize-generic.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/generic/RTFileQuerySize-generic.cpp	(revision 80585)
@@ -38,5 +38,5 @@
 
 
-RTDECL(int) RTFileQuerySize(const char *pszPath, uint64_t *pcbFile)
+RTDECL(int) RTFileQuerySizeByPath(const char *pszPath, uint64_t *pcbFile)
 {
     RTFSOBJINFO ObjInfo;
Index: /trunk/src/VBox/Runtime/r0drv/darwin/fileio-r0drv-darwin.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r0drv/darwin/fileio-r0drv-darwin.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/r0drv/darwin/fileio-r0drv-darwin.cpp	(revision 80585)
@@ -236,5 +236,5 @@
 
 
-RTDECL(int) RTFileGetSize(RTFILE hFile, uint64_t *pcbSize)
+RTDECL(int) RTFileQuerySize(RTFILE hFile, uint64_t *pcbSize)
 {
     RTFILEINT *pThis = hFile;
@@ -288,5 +288,5 @@
         {
             uint64_t cbFile = 0;
-            int rc = RTFileGetSize(hFile, &cbFile);
+            int rc = RTFileQuerySize(hFile, &cbFile);
             if (RT_SUCCESS(rc))
                 offNew = cbFile + offSeek;
Index: /trunk/src/VBox/Runtime/r3/fileio.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/fileio.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/r3/fileio.cpp	(revision 80585)
@@ -227,10 +227,10 @@
  *          -1 on failure, the file position is undefined.
  * @param   File        Handle to the file.
- * @see     RTFileGetMaxSizeEx.
+ * @see     RTFileQueryMaxSizeEx.
  */
 RTR3DECL(RTFOFF) RTFileGetMaxSize(RTFILE File)
 {
     RTFOFF cbMax;
-    int rc = RTFileGetMaxSizeEx(File, &cbMax);
+    int rc = RTFileQueryMaxSizeEx(File, &cbMax);
     return RT_SUCCESS(rc) ? cbMax : -1;
 }
@@ -317,10 +317,10 @@
      */
     uint64_t cbFile1;
-    int rc = RTFileGetSize(hFile1, &cbFile1);
+    int rc = RTFileQuerySize(hFile1, &cbFile1);
     if (RT_FAILURE(rc))
         return rc;
 
     uint64_t cbFile2;
-    rc = RTFileGetSize(hFile1, &cbFile2);
+    rc = RTFileQuerySize(hFile1, &cbFile2);
     if (RT_FAILURE(rc))
         return rc;
Index: /trunk/src/VBox/Runtime/r3/posix/fileio-posix.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/posix/fileio-posix.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/r3/posix/fileio-posix.cpp	(revision 80585)
@@ -670,5 +670,5 @@
 
 
-RTR3DECL(int) RTFileGetSize(RTFILE hFile, uint64_t *pcbSize)
+RTR3DECL(int) RTFileQuerySize(RTFILE hFile, uint64_t *pcbSize)
 {
     /*
@@ -746,5 +746,5 @@
 
 
-RTR3DECL(int) RTFileGetMaxSizeEx(RTFILE hFile, PRTFOFF pcbMax)
+RTR3DECL(int) RTFileQueryMaxSizeEx(RTFILE hFile, PRTFOFF pcbMax)
 {
     /*
Index: /trunk/src/VBox/Runtime/r3/win/fileio-win.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/win/fileio-win.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/r3/win/fileio-win.cpp	(revision 80585)
@@ -798,5 +798,5 @@
 
 
-RTR3DECL(int)  RTFileGetSize(RTFILE hFile, uint64_t *pcbSize)
+RTR3DECL(int)  RTFileQuerySize(RTFILE hFile, uint64_t *pcbSize)
 {
     /*
@@ -849,5 +849,5 @@
 
 
-RTR3DECL(int) RTFileGetMaxSizeEx(RTFILE hFile, PRTFOFF pcbMax)
+RTR3DECL(int) RTFileQueryMaxSizeEx(RTFILE hFile, PRTFOFF pcbMax)
 {
     /** @todo r=bird:
Index: /trunk/src/VBox/Runtime/r3/xml.cpp
===================================================================
--- /trunk/src/VBox/Runtime/r3/xml.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/r3/xml.cpp	(revision 80585)
@@ -2290,5 +2290,5 @@
         /* Make a backup of any existing file (ignore failure). */
         uint64_t cbPrevFile;
-        rc = RTFileQuerySize(pcszFilename, &cbPrevFile);
+        rc = RTFileQuerySizeByPath(pcszFilename, &cbPrevFile);
         if (RT_SUCCESS(rc) && cbPrevFile >= 16)
             RTFileRename(pcszFilename, szPrevFilename, RTPATHRENAME_FLAGS_REPLACE);
Index: /trunk/src/VBox/Runtime/testcase/Makefile.kmk
===================================================================
--- /trunk/src/VBox/Runtime/testcase/Makefile.kmk	(revision 80584)
+++ /trunk/src/VBox/Runtime/testcase/Makefile.kmk	(revision 80585)
@@ -67,5 +67,5 @@
 	tstRTFileAio \
 	tstRTFileAppend-1 \
-	tstRTFileGetSize-1 \
+	tstRTFileQuerySize-1 \
 	tstRTFileModeStringToFlags \
 	tstFileLock \
@@ -362,6 +362,6 @@
 tstRTFileAppend-1_SOURCES = tstRTFileAppend-1.cpp
 
-tstRTFileGetSize-1_TEMPLATE = VBOXR3TSTEXE
-tstRTFileGetSize-1_SOURCES = tstRTFileGetSize-1.cpp
+tstRTFileQuerySize-1_TEMPLATE = VBOXR3TSTEXE
+tstRTFileQuerySize-1_SOURCES = tstRTFileQuerySize-1.cpp
 
 tstRTFileModeStringToFlags_TEMPLATE = VBOXR3TSTEXE
Index: /trunk/src/VBox/Runtime/testcase/tstFile.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstFile.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/testcase/tstFile.cpp	(revision 80585)
@@ -51,13 +51,13 @@
 
     RTFOFF cbMax = -2;
-    rc = RTFileGetMaxSizeEx(File, &cbMax);
-    if (RT_FAILURE(rc))
-    {
-        RTPrintf("tstFile: RTFileGetMaxSizeEx failed: %Rrc\n", rc);
+    rc = RTFileQueryMaxSizeEx(File, &cbMax);
+    if (RT_FAILURE(rc))
+    {
+        RTPrintf("tstFile: RTFileQueryMaxSizeEx failed: %Rrc\n", rc);
         cErrors++;
     }
     else if (cbMax <= 0)
     {
-        RTPrintf("tstFile: RTFileGetMaxSizeEx failed: cbMax=%RTfoff\n", cbMax);
+        RTPrintf("tstFile: RTFileQueryMaxSizeEx failed: cbMax=%RTfoff\n", cbMax);
         cErrors++;
     }
@@ -80,5 +80,5 @@
     {
         uint64_t cb;
-        rc = RTFileGetSize(File, &cb);
+        rc = RTFileQuerySize(File, &cb);
         if (RT_FAILURE(rc))
         {
@@ -88,5 +88,5 @@
         else if (cb != _2G + _1M)
         {
-            RTPrintf("RTFileGetSize return %RX64 bytes, expected %RX64.\n", cb, _2G + _1M);
+            RTPrintf("RTFileQuerySize return %RX64 bytes, expected %RX64.\n", cb, _2G + _1M);
             cErrors++;
         }
Index: /trunk/src/VBox/Runtime/testcase/tstRTDvm.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstRTDvm.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/testcase/tstRTDvm.cpp	(revision 80585)
@@ -190,9 +190,9 @@
 
     uint64_t cb = 0;
-    rc = RTVfsFileGetSize(hVfsDisk, &cb);
+    rc = RTVfsFileQuerySize(hVfsDisk, &cb);
     if (   RT_FAILURE(rc)
         || cb % 512 != 0) /* Assume 512 byte sector size. */
     {
-        RTTestIFailed("RTVfsFileGetSize -> %Rrc", rc);
+        RTTestIFailed("RTVfsFileQuerySize -> %Rrc", rc);
         return RTTestSummaryAndDestroy(hTest);
     }
Index: unk/src/VBox/Runtime/testcase/tstRTFileGetSize-1.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstRTFileGetSize-1.cpp	(revision 80584)
+++ 	(revision )
@@ -1,106 +1,0 @@
-/* $Id$ */
-/** @file
- * IPRT Testcase - RTFileGetSize.
- */
-
-/*
- * Copyright (C) 2011-2019 Oracle Corporation
- *
- * This file is part of VirtualBox Open Source Edition (OSE), as
- * available from http://www.virtualbox.org. This file is free software;
- * you can redistribute it and/or modify it under the terms of the GNU
- * General Public License (GPL) as published by the Free Software
- * Foundation, in version 2 as it comes in the "COPYING" file of the
- * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
- * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
- *
- * The contents of this file may alternatively be used under the terms
- * of the Common Development and Distribution License Version 1.0
- * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
- * VirtualBox OSE distribution, in which case the provisions of the
- * CDDL are applicable instead of those of the GPL.
- *
- * You may elect to license modified versions of this file under the
- * terms and conditions of either the GPL or the CDDL or both.
- */
-
-
-/*********************************************************************************************************************************
-*   Header Files                                                                                                                 *
-*********************************************************************************************************************************/
-#include <iprt/file.h>
-
-#include <iprt/err.h>
-#include <iprt/initterm.h>
-#include <iprt/path.h>
-#include <iprt/string.h>
-#include <iprt/test.h>
-
-
-static void test1(const char *pszSubTest, const char *pszFilename)
-{
-    int rc;
-    RTTestISub(pszSubTest);
-
-    RTFILE hFile;
-    rc = RTFileOpen(&hFile, pszFilename, RTFILE_O_READ | RTFILE_O_DENY_NONE | RTFILE_O_OPEN);
-    if (RT_FAILURE(rc))
-    {
-        if (   rc == VERR_ACCESS_DENIED
-            || rc == VERR_PERMISSION_DENIED
-            || rc == VERR_FILE_NOT_FOUND)
-        {
-            RTTestIPrintf(RTTESTLVL_ALWAYS, "Cannot access '%s', skipping.", pszFilename);
-            return;
-        }
-        RTTESTI_CHECK_RC_RETV(RTFileOpen(&hFile, pszFilename, RTFILE_O_READ | RTFILE_O_DENY_NONE | RTFILE_O_OPEN), VINF_SUCCESS);
-    }
-
-    uint64_t    cbFile = UINT64_MAX - 42;
-    RTTESTI_CHECK_RC(rc = RTFileGetSize(hFile, &cbFile), VINF_SUCCESS);
-    if (RT_SUCCESS(rc))
-    {
-        RTTESTI_CHECK(cbFile != UINT64_MAX - 42);
-        RTTestIValue(pszSubTest, cbFile, RTTESTUNIT_BYTES);
-    }
-
-    RTFileClose(hFile);
-    RTTestISubDone();
-}
-
-
-int main(int argc, char **argv)
-{
-    RTTEST hTest;
-    int rc = RTTestInitAndCreate("tstRTFileGetSize-1", &hTest);
-    if (rc)
-        return rc;
-    RTTestBanner(hTest);
-
-    for (int i = 0; i < argc; i++)
-    {
-        char *pszNm = RTPathFilename(argv[i]);
-        if (!pszNm)
-            pszNm = argv[i];
-        test1(pszNm, argv[i]);
-    }
-
-#ifdef RT_OS_WINDOWS
-    test1("//./PhysicalDrive0", "//./PhysicalDrive0");
-    test1("//./HarddiskVolume1", "//./HarddiskVolume1");
-    test1("//./null", "//./nul");
-#else
-    test1("/dev/null", "/dev/null");
-# ifdef RT_OS_LINUX
-    test1("/dev/sda",  "/dev/sda");
-    test1("/dev/sda1", "/dev/sda1");
-    test1("/dev/sda5", "/dev/sda5");
-# endif
-#endif
-
-    /*
-     * Summary.
-     */
-    return RTTestSummaryAndDestroy(hTest);
-}
-
Index: /trunk/src/VBox/Runtime/testcase/tstRTFileQuerySize-1.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstRTFileQuerySize-1.cpp	(revision 80585)
+++ /trunk/src/VBox/Runtime/testcase/tstRTFileQuerySize-1.cpp	(revision 80585)
@@ -0,0 +1,106 @@
+/* $Id$ */
+/** @file
+ * IPRT Testcase - RTFileQuerySize.
+ */
+
+/*
+ * Copyright (C) 2011-2019 Oracle Corporation
+ *
+ * This file is part of VirtualBox Open Source Edition (OSE), as
+ * available from http://www.virtualbox.org. This file is free software;
+ * you can redistribute it and/or modify it under the terms of the GNU
+ * General Public License (GPL) as published by the Free Software
+ * Foundation, in version 2 as it comes in the "COPYING" file of the
+ * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
+ * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
+ *
+ * The contents of this file may alternatively be used under the terms
+ * of the Common Development and Distribution License Version 1.0
+ * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
+ * VirtualBox OSE distribution, in which case the provisions of the
+ * CDDL are applicable instead of those of the GPL.
+ *
+ * You may elect to license modified versions of this file under the
+ * terms and conditions of either the GPL or the CDDL or both.
+ */
+
+
+/*********************************************************************************************************************************
+*   Header Files                                                                                                                 *
+*********************************************************************************************************************************/
+#include <iprt/file.h>
+
+#include <iprt/err.h>
+#include <iprt/initterm.h>
+#include <iprt/path.h>
+#include <iprt/string.h>
+#include <iprt/test.h>
+
+
+static void test1(const char *pszSubTest, const char *pszFilename)
+{
+    int rc;
+    RTTestISub(pszSubTest);
+
+    RTFILE hFile;
+    rc = RTFileOpen(&hFile, pszFilename, RTFILE_O_READ | RTFILE_O_DENY_NONE | RTFILE_O_OPEN);
+    if (RT_FAILURE(rc))
+    {
+        if (   rc == VERR_ACCESS_DENIED
+            || rc == VERR_PERMISSION_DENIED
+            || rc == VERR_FILE_NOT_FOUND)
+        {
+            RTTestIPrintf(RTTESTLVL_ALWAYS, "Cannot access '%s', skipping.", pszFilename);
+            return;
+        }
+        RTTESTI_CHECK_RC_RETV(RTFileOpen(&hFile, pszFilename, RTFILE_O_READ | RTFILE_O_DENY_NONE | RTFILE_O_OPEN), VINF_SUCCESS);
+    }
+
+    uint64_t    cbFile = UINT64_MAX - 42;
+    RTTESTI_CHECK_RC(rc = RTFileQuerySize(hFile, &cbFile), VINF_SUCCESS);
+    if (RT_SUCCESS(rc))
+    {
+        RTTESTI_CHECK(cbFile != UINT64_MAX - 42);
+        RTTestIValue(pszSubTest, cbFile, RTTESTUNIT_BYTES);
+    }
+
+    RTFileClose(hFile);
+    RTTestISubDone();
+}
+
+
+int main(int argc, char **argv)
+{
+    RTTEST hTest;
+    int rc = RTTestInitAndCreate("tstRTFileQuerySize-1", &hTest);
+    if (rc)
+        return rc;
+    RTTestBanner(hTest);
+
+    for (int i = 0; i < argc; i++)
+    {
+        char *pszNm = RTPathFilename(argv[i]);
+        if (!pszNm)
+            pszNm = argv[i];
+        test1(pszNm, argv[i]);
+    }
+
+#ifdef RT_OS_WINDOWS
+    test1("//./PhysicalDrive0", "//./PhysicalDrive0");
+    test1("//./HarddiskVolume1", "//./HarddiskVolume1");
+    test1("//./null", "//./nul");
+#else
+    test1("/dev/null", "/dev/null");
+# ifdef RT_OS_LINUX
+    test1("/dev/sda",  "/dev/sda");
+    test1("/dev/sda1", "/dev/sda1");
+    test1("/dev/sda5", "/dev/sda5");
+# endif
+#endif
+
+    /*
+     * Summary.
+     */
+    return RTTestSummaryAndDestroy(hTest);
+}
+
Index: /trunk/src/VBox/Runtime/testcase/tstRTFilesystem.cpp
===================================================================
--- /trunk/src/VBox/Runtime/testcase/tstRTFilesystem.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/testcase/tstRTFilesystem.cpp	(revision 80585)
@@ -60,8 +60,8 @@
     uint64_t cbFs = 0;
 
-    rc = RTVfsFileGetSize(hVfsFile, &cbFs);
+    rc = RTVfsFileQuerySize(hVfsFile, &cbFs);
     if (RT_FAILURE(rc))
     {
-        RTTestIFailed("RTVfsFileGetSize -> %Rrc", rc);
+        RTTestIFailed("RTVfsFileQuerySize -> %Rrc", rc);
         return rc;
     }
Index: /trunk/src/VBox/Runtime/tools/RTLdrCheckImports.cpp
===================================================================
--- /trunk/src/VBox/Runtime/tools/RTLdrCheckImports.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/tools/RTLdrCheckImports.cpp	(revision 80585)
@@ -277,5 +277,5 @@
                 /* Read it into a memory buffer. */
                 uint64_t cbFile;
-                rc = RTVfsFileGetSize(hVfsFile, &cbFile);
+                rc = RTVfsFileQuerySize(hVfsFile, &cbFile);
                 if (RT_SUCCESS(rc))
                 {
@@ -375,5 +375,5 @@
                 }
                 else
-                    RTMsgError("%s: %s: RTVfsFileGetSize failed on export file: %Rrc", pszImage, szPath, rc);
+                    RTMsgError("%s: %s: RTVfsFileQuerySize failed on export file: %Rrc", pszImage, szPath, rc);
                 RTVfsFileRelease(hVfsFile);
                 return rc;
Index: /trunk/src/VBox/Runtime/tools/RTSignTool.cpp
===================================================================
--- /trunk/src/VBox/Runtime/tools/RTSignTool.cpp	(revision 80584)
+++ /trunk/src/VBox/Runtime/tools/RTSignTool.cpp	(revision 80585)
@@ -781,5 +781,5 @@
                             uint32_t const  cbWinCert = RT_UOFFSETOF(WIN_CERTIFICATE, bCertificate);
                             uint64_t        offCur    = 0;
-                            rc = RTFileGetSize(hFile, &offCur);
+                            rc = RTFileQuerySize(hFile, &offCur);
                             if (   RT_SUCCESS(rc)
                                 && offCur < _2G)
@@ -860,5 +860,5 @@
                                 RTMsgError("File to big: %'RU64 bytes", offCur);
                             else
-                                RTMsgError("RTFileGetSize failed: %Rrc", rc);
+                                RTMsgError("RTFileQuerySize failed: %Rrc", rc);
                         }
                     }
Index: /trunk/src/VBox/Storage/VD.cpp
===================================================================
--- /trunk/src/VBox/Storage/VD.cpp	(revision 80584)
+++ /trunk/src/VBox/Storage/VD.cpp	(revision 80585)
@@ -3250,5 +3250,5 @@
     PVDIIOFALLBACKSTORAGE pStorage = (PVDIIOFALLBACKSTORAGE)pvStorage;
 
-    return RTFileGetSize(pStorage->File, pcbSize);
+    return RTFileQuerySize(pStorage->File, pcbSize);
 }
 
Index: /trunk/src/VBox/Storage/VISO.cpp
===================================================================
--- /trunk/src/VBox/Storage/VISO.cpp	(revision 80584)
+++ /trunk/src/VBox/Storage/VISO.cpp	(revision 80585)
@@ -344,5 +344,5 @@
                                         {
                                             uint64_t cbImage;
-                                            rc = RTVfsFileGetSize(hVfsFile, &cbImage);
+                                            rc = RTVfsFileQuerySize(hVfsFile, &cbImage);
                                             if (RT_SUCCESS(rc))
                                             {
Index: /trunk/src/VBox/Storage/testcase/VDIoBackend.cpp
===================================================================
--- /trunk/src/VBox/Storage/testcase/VDIoBackend.cpp	(revision 80584)
+++ /trunk/src/VBox/Storage/testcase/VDIoBackend.cpp	(revision 80585)
@@ -222,5 +222,5 @@
     }
     else
-        rc = RTFileGetSize(pIoStorage->u.hFile, pcbSize);
+        rc = RTFileQuerySize(pIoStorage->u.hFile, pcbSize);
 
     return rc;
Index: /trunk/src/VBox/Storage/testcase/tstVDIo.cpp
===================================================================
--- /trunk/src/VBox/Storage/testcase/tstVDIo.cpp	(revision 80584)
+++ /trunk/src/VBox/Storage/testcase/tstVDIo.cpp	(revision 80585)
@@ -1669,5 +1669,5 @@
         if (RT_SUCCESS(rc))
         {
-            rc = RTFileGetSize(hFile, &cbPattern);
+            rc = RTFileQuerySize(hFile, &cbPattern);
             if (RT_SUCCESS(rc))
             {
Index: /trunk/src/VBox/VMM/VMMR3/PDMAsyncCompletionFile.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR3/PDMAsyncCompletionFile.cpp	(revision 80584)
+++ /trunk/src/VBox/VMM/VMMR3/PDMAsyncCompletionFile.cpp	(revision 80585)
@@ -950,5 +950,5 @@
             uint64_t cbSize;
 
-            rc = RTFileGetSize(hFile, &cbSize);
+            rc = RTFileQuerySize(hFile, &cbSize);
 
             if (RT_SUCCESS(rc) && ((cbSize % 512) == 0))
@@ -1008,5 +1008,5 @@
         pEpFile->fFlags = fFileFlags;
 
-        rc = RTFileGetSize(pEpFile->hFile, (uint64_t *)&pEpFile->cbFile);
+        rc = RTFileQuerySize(pEpFile->hFile, (uint64_t *)&pEpFile->cbFile);
         if (RT_SUCCESS(rc))
         {
Index: /trunk/src/VBox/VMM/VMMR3/SSM.cpp
===================================================================
--- /trunk/src/VBox/VMM/VMMR3/SSM.cpp	(revision 80584)
+++ /trunk/src/VBox/VMM/VMMR3/SSM.cpp	(revision 80585)
@@ -2003,5 +2003,5 @@
 static DECLCALLBACK(int) ssmR3FileSize(void *pvUser, uint64_t *pcb)
 {
-    return RTFileGetSize((RTFILE)(uintptr_t)pvUser, pcb);
+    return RTFileQuerySize((RTFILE)(uintptr_t)pvUser, pcb);
 }
 
Index: /trunk/src/VBox/VMM/testcase/tstAnimate.cpp
===================================================================
--- /trunk/src/VBox/VMM/testcase/tstAnimate.cpp	(revision 80584)
+++ /trunk/src/VBox/VMM/testcase/tstAnimate.cpp	(revision 80585)
@@ -197,5 +197,5 @@
     RTPrintf("info: running script...\n");
     uint64_t cb;
-    int rc = RTFileGetSize(File, &cb);
+    int rc = RTFileQuerySize(File, &cb);
     if (RT_SUCCESS(rc))
     {
@@ -804,5 +804,5 @@
         if (FileRawMem != NIL_RTFILE)
         {
-            rc = RTFileGetSize(FileRawMem, &cbMem);
+            rc = RTFileQuerySize(FileRawMem, &cbMem);
             AssertReleaseRC(rc);
             cbMem -= offRawMem;
Index: /trunk/src/VBox/ValidationKit/tests/unittests/tdUnitTest1.py
===================================================================
--- /trunk/src/VBox/ValidationKit/tests/unittests/tdUnitTest1.py	(revision 80584)
+++ /trunk/src/VBox/ValidationKit/tests/unittests/tdUnitTest1.py	(revision 80585)
@@ -74,5 +74,5 @@
             'testcase/tstRTSemRW': '',                  # line 338: RTSemRWReleaseRead(hSemRW): got VERR_ACCESS_DENIED
             'testcase/tstRTStrAlloc': '',               # VERR_NO_STR_MEMORY!
-            'testcase/tstRTFileGetSize-1': '',          # VERR_DEV_IO_ERROR on /dev/null!
+            'testcase/tstRTFileQuerySize-1': '',        # VERR_DEV_IO_ERROR on /dev/null!
         },
         'solaris.amd64': {
Index: /trunk/src/VBox/ValidationKit/utils/fs/FsPerf.cpp
===================================================================
--- /trunk/src/VBox/ValidationKit/utils/fs/FsPerf.cpp	(revision 80584)
+++ /trunk/src/VBox/ValidationKit/utils/fs/FsPerf.cpp	(revision 80585)
@@ -3414,5 +3414,5 @@
                                      RTFILE_O_CREATE_REPLACE | RTFILE_O_DENY_NONE | RTFILE_O_READWRITE), VINF_SUCCESS);
     uint64_t cbFile = UINT64_MAX;
-    RTTESTI_CHECK_RC(RTFileGetSize(hFile1, &cbFile), VINF_SUCCESS);
+    RTTESTI_CHECK_RC(RTFileQuerySize(hFile1, &cbFile), VINF_SUCCESS);
     RTTESTI_CHECK(cbFile == 0);
 
@@ -3431,5 +3431,5 @@
 
         RTTESTI_CHECK_RC(RTFileSetSize(hFile1, cbNew), VINF_SUCCESS);
-        RTTESTI_CHECK_RC(RTFileGetSize(hFile1, &cbFile), VINF_SUCCESS);
+        RTTESTI_CHECK_RC(RTFileQuerySize(hFile1, &cbFile), VINF_SUCCESS);
         RTTESTI_CHECK_MSG(cbFile == cbNew, ("cbFile=%#RX64 cbNew=%#RX64\n", cbFile, cbNew));
 
@@ -6196,5 +6196,5 @@
     RTTESTI_CHECK_RC(RTFileSetSize(hFile0, 8000), VINF_SUCCESS);
     uint64_t cbFile = 0;
-    RTTESTI_CHECK_RC(RTFileGetSize(hFile0, &cbFile), VINF_SUCCESS);
+    RTTESTI_CHECK_RC(RTFileQuerySize(hFile0, &cbFile), VINF_SUCCESS);
     RTTESTI_CHECK_MSG(cbFile == 8000, ("cbFile=%u\n", cbFile));
     RTTESTI_CHECK_RC(RTFileRead(hFile0, abBuf, 1, NULL), VERR_EOF);
@@ -6207,5 +6207,5 @@
     RTTESTI_CHECK_RC(RTFileSetSize(hFile0, 5000), VINF_SUCCESS);
     RTTESTI_CHECK_RC(RTFileRead(hFile0, abBuf, 1, NULL), VERR_EOF);
-    RTTESTI_CHECK_RC(RTFileGetSize(hFile0, &cbFile), VINF_SUCCESS);
+    RTTESTI_CHECK_RC(RTFileQuerySize(hFile0, &cbFile), VINF_SUCCESS);
     RTTESTI_CHECK_MSG(cbFile == 5000, ("cbFile=%u\n", cbFile));
 
@@ -6215,5 +6215,5 @@
     RTTESTI_CHECK_RC(RTFileSetSize(hFile0, 10000), VINF_SUCCESS);
     RTTESTI_CHECK_RC(FsPerfCommsSend("truncate 0 4000" FSPERF_EOF_STR), VINF_SUCCESS);
-    RTTESTI_CHECK_RC(RTFileGetSize(hFile0, &cbFile), VINF_SUCCESS);
+    RTTESTI_CHECK_RC(RTFileQuerySize(hFile0, &cbFile), VINF_SUCCESS);
     RTTESTI_CHECK_MSG(cbFile == 4000, ("cbFile=%u\n", cbFile));
     RTTESTI_CHECK_RC(RTFileRead(hFile0, abBuf, 1, NULL), VERR_EOF);

Index: /trunk/src/VBox/Storage/DMG.cpp
===================================================================
--- /trunk/src/VBox/Storage/DMG.cpp	(revision 80584)
+++ /trunk/src/VBox/Storage/DMG.cpp	(revision 80585)
@@ -502,5 +502,5 @@
 
 /**
  * vdIfIoIntFileGetSize / RTVfsFileGetSize wrapper.
  */
 static int dmgWrapFileGetSize(PDMGIMAGE pThis, uint64_t *pcbFile)
@@ -510,5 +510,5 @@
         rc = vdIfIoIntFileGetSize(pThis->pIfIoXxx, pThis->pStorage, pcbFile);
     else
-        rc = RTVfsFileGetSize(pThis->hDmgFileInXar, pcbFile);
+        rc = RTVfsFileQuerySize(pThis->hDmgFileInXar, pcbFile);
     return rc;
 }
@@ -1788,5 +1788,5 @@
         rc = vdIfIoIntFileGetSize(pIfIo, pStorage, &cbFile);
     else
-        rc = RTVfsFileGetSize(hDmgFileInXar, &cbFile);
+        rc = RTVfsFileQuerySize(hDmgFileInXar, &cbFile);
     if (   RT_SUCCESS(rc)
         && cbFile >= sizeof(DMGUDIF))
@@ -502,5 +502,5 @@
 
 /**
- * vdIfIoIntFileGetSize / RTVfsFileGetSize wrapper.
+ * vdIfIoIntFileGetSize / RTVfsFileQuerySize wrapper.
  */
 static int dmgWrapFileGetSize(PDMGIMAGE pThis, uint64_t *pcbFile)